@@ -10,14 +10,6 @@ pub mod ansible_facts;
 pub use self::ansible_facts::AnsibleFacts;
 pub mod ansible_facts_request;
 pub use self::ansible_facts_request::AnsibleFactsRequest;
-pub mod appliance;
-pub use self::appliance::Appliance;
-pub mod appliance_key_pair;
-pub use self::appliance_key_pair::ApplianceKeyPair;
-pub mod appliance_public_key;
-pub use self::appliance_public_key::AppliancePublicKey;
-pub mod appliance_request;
-pub use self::appliance_request::ApplianceRequest;
 pub mod artifact_types_enum;
 pub use self::artifact_types_enum::ArtifactTypesEnum;
 pub mod callback_token_auth_request;
@@ -40,10 +32,18 @@ pub mod command_enum;
 pub use self::command_enum::CommandEnum;
 pub mod detail_response;
 pub use self::detail_response::DetailResponse;
+pub mod device;
+pub use self::device::Device;
 pub mod device_calibration;
 pub use self::device_calibration::DeviceCalibration;
 pub mod device_calibration_request;
 pub use self::device_calibration_request::DeviceCalibrationRequest;
+pub mod device_key_pair;
+pub use self::device_key_pair::DeviceKeyPair;
+pub mod device_public_key;
+pub use self::device_public_key::DevicePublicKey;
+pub mod device_request;
+pub use self::device_request::DeviceRequest;
 pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod error_detail;
@@ -122,16 +122,16 @@ pub mod paginated_alert_list;
 pub use self::paginated_alert_list::PaginatedAlertList;
 pub mod paginated_ansible_facts_list;
 pub use self::paginated_ansible_facts_list::PaginatedAnsibleFactsList;
-pub mod paginated_appliance_list;
-pub use self::paginated_appliance_list::PaginatedApplianceList;
-pub mod paginated_appliance_public_key_list;
-pub use self::paginated_appliance_public_key_list::PaginatedAppliancePublicKeyList;
 pub mod paginated_camera_list;
 pub use self::paginated_camera_list::PaginatedCameraList;
 pub mod paginated_cloud_io_t_device_list;
 pub use self::paginated_cloud_io_t_device_list::PaginatedCloudIoTDeviceList;
 pub mod paginated_device_calibration_list;
 pub use self::paginated_device_calibration_list::PaginatedDeviceCalibrationList;
+pub mod paginated_device_list;
+pub use self::paginated_device_list::PaginatedDeviceList;
+pub mod paginated_device_public_key_list;
+pub use self::paginated_device_public_key_list::PaginatedDevicePublicKeyList;
 pub mod paginated_experiment_device_config_list;
 pub use self::paginated_experiment_device_config_list::PaginatedExperimentDeviceConfigList;
 pub mod paginated_experiment_list;
@@ -172,14 +172,14 @@ pub mod patched_alert_request;
 pub use self::patched_alert_request::PatchedAlertRequest;
 pub mod patched_ansible_facts_request;
 pub use self::patched_ansible_facts_request::PatchedAnsibleFactsRequest;
-pub mod patched_appliance_request;
-pub use self::patched_appliance_request::PatchedApplianceRequest;
 pub mod patched_camera_request;
 pub use self::patched_camera_request::PatchedCameraRequest;
 pub mod patched_cloud_io_t_device_request;
 pub use self::patched_cloud_io_t_device_request::PatchedCloudIoTDeviceRequest;
 pub mod patched_device_calibration_request;
 pub use self::patched_device_calibration_request::PatchedDeviceCalibrationRequest;
+pub mod patched_device_request;
+pub use self::patched_device_request::PatchedDeviceRequest;
 pub mod patched_octo_print_device_request;
 pub use self::patched_octo_print_device_request::PatchedOctoPrintDeviceRequest;
 pub mod patched_print_session_request;
